@@ -20,7 +20,6 @@ This class uses L<Data::Dumper> them to print the buffer content to C<STDOUT>.
 
 use Moose;
 use namespace::autoclean;
-use Data::Dumper;
 
 extends 'Siebel::Srvrmgr::Daemon::Action';
 
@@ -50,11 +49,11 @@ L<Siebel::Srvrmgr::Daemon::Action>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel Monitoring Tools.
 
