@@ -50,7 +50,7 @@ override 'do_parsed' => sub {
     my $self = shift;
     my $obj  = shift;
 
-    if ( $obj->isa('Siebel::Srvrmgr::ListParser::Output::ListComp') ) {
+    if ( $obj->isa( $self->get_exp_output() ) ) {
 
         my $servers_ref = $obj->get_servers();
 
@@ -91,6 +91,12 @@ override 'do_parsed' => sub {
 
 };
 
+override '_build_exp_output' => sub {
+
+    return 'Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp';
+
+};
+
 =pod
 
 =head1 SEE ALSO
