@@ -79,7 +79,6 @@ use Siebel::Srvrmgr::IPC;
 use IO::Select;
 use Encode;
 use Carp qw(longmess);
-use Socket qw(:crlf);
 use Siebel::Srvrmgr;
 
 extends 'Siebel::Srvrmgr::Daemon';
@@ -444,34 +443,26 @@ sub run {
 
     my ( $read_h, $write_h, $error_h );
 
-# :WORKAROUND:31/07/2013 14:42:33:: must initialize the Log::Log4perl after forking the srvrmgr to avoid sharing filehandles
     unless ( $self->has_pid() ) {
 
-        $logger = $self->_create_child();
+        confess( $self->get_bin()
+              . ' returned un unrecoverable error, aborting execution' )
+          unless ( $self->_create_child() );
 
-        unless ( ( defined($logger) ) and ( ref($logger) ) ) {
-
-            die( $self->get_bin()
-                  . ' returned un unrecoverable error, aborting execution' )
-
-        }
-        else {
-
-            weaken($logger);
-
-        }
+# :WORKAROUND:31/07/2013 14:42:33:: must initialize the Log::Log4perl after forking the srvrmgr to avoid sharing filehandles
+        $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
 
     }
     else {
 
         $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
-        weaken($logger);
         $logger->info( 'Reusing PID ', $self->get_pid() )
           if ( $logger->is_debug() );
         $ignore_output = 1;
 
     }
 
+    weaken($logger);
     $logger->info('Starting run method');
 
 # :WARNING:28/06/2011 19:47:26:: reading the output is hanging without a dummy input
@@ -488,12 +479,12 @@ sub run {
         }
     );
 
-    my $parser   = Siebel::Srvrmgr::ListParser->new();
+    my $parser   = $self->create_parser();
     my $select   = IO::Select->new();
     my $data_ref = $self->_create_handle_buffer( $select, $logger );
 
     my $prompt_regex = qr/srvrmgr(\:\w+)?>\s(.*)?$/;
-    my $eol_regex    = qr/$CRLF$/;
+    my $eol_regex    = qr/\015\012$/;
 
     $logger->debug( 'sysread buffer size is ' . $self->get_buffer_size() )
       if ( $logger->is_debug() );
@@ -819,15 +810,15 @@ sub _create_handle_buffer {
 
       SWITCH: {
 
-            if ( $/ eq CR ) {
+            if ( $/ eq \015 ) {
                 $logger->debug( $assert . 'CR' );
                 last SWITCH;
             }
-            if ( $/ eq CRLF ) {
+            if ( $/ eq ( \015 . \012 ) ) {
                 $logger->debug( $assert . 'CRLF' );
                 last SWITCH;
             }
-            if ( $/ eq LF ) {
+            if ( $/ eq \012 ) {
                 $logger->debug( $assert . 'LF' );
                 last SWITCH;
             }
@@ -891,7 +882,7 @@ sub _create_child {
     else {
 
         $self->_set_child_runs(0);
-        return $logger;
+        return 1;
 
     }
 
@@ -1036,7 +1027,7 @@ sub _process_stdout {
 
             }
 
-# no prompt detection, keep reading output from srvrmgr
+            # no prompt detection, keep reading output from srvrmgr
             else { push( @{$buffer_ref}, $line ); }
 
         }
@@ -1154,7 +1145,7 @@ sub _my_cleanup {
 
         if ( $logger->is_info() ) {
 
-            $logger->info( 'No child process to terminate' );
+            $logger->info('No child process to terminate');
 
         }
 
