@@ -61,6 +61,20 @@ has name => ( isa => 'Str', is => 'ro', required => 1, reader => 'get_name' );
 
 =pod
 
+=head2 comp_attribs
+
+A array reference with the components attributes names
+
+=cut
+
+has 'comp_attribs' => (
+    is      => 'ro',
+    isa     => 'ArrayRef',
+    reader  => 'get_comp_attribs'
+);
+
+=pod
+
 =head1 METHODS
 
 =head2 get_data
@@ -164,7 +178,7 @@ sub get_comp_data {
 
 =head1 SEE ALSO
 
-=over 4
+=over
 
 =item *
 
@@ -186,11 +200,11 @@ L<Siebel::Srvrmgr::ListParser::Output::ListComp::Comp>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>.
 
 This file is part of Siebel Monitoring Tools.
 
@@ -205,7 +219,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
+along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
